@@ -45,6 +45,97 @@
 namespace ZenLib
 {
 
+//---------------------------------------------------------------------------
+// Debug
+#ifdef ZENLIB_DEBUG
+    #include <stdio.h>
+    #include <windows.h>
+    namespace ZenLib_Dir_Debug
+    {
+        FILE* F;
+        std::string Debug;
+        SYSTEMTIME st_In;
+
+        void Debug_Open(bool Out)
+        {
+            F=fopen("C:\\Temp\\ZenLib_Debug.txt", "a+t");
+            Debug.clear();
+            SYSTEMTIME st;
+            GetLocalTime( &st );
+
+            char Duration[100];
+            if (Out)
+            {
+                FILETIME ft_In;
+                if (SystemTimeToFileTime(&st_In, &ft_In))
+                {
+                    FILETIME ft_Out;
+                    if (SystemTimeToFileTime(&st, &ft_Out))
+                    {
+                        ULARGE_INTEGER UI_In;
+                        UI_In.HighPart=ft_In.dwHighDateTime;
+                        UI_In.LowPart=ft_In.dwLowDateTime;
+
+                        ULARGE_INTEGER UI_Out;
+                        UI_Out.HighPart=ft_Out.dwHighDateTime;
+                        UI_Out.LowPart=ft_Out.dwLowDateTime;
+
+                        ULARGE_INTEGER UI_Diff;
+                        UI_Diff.QuadPart=UI_Out.QuadPart-UI_In.QuadPart;
+
+                        FILETIME ft_Diff;
+                        ft_Diff.dwHighDateTime=UI_Diff.HighPart;
+                        ft_Diff.dwLowDateTime=UI_Diff.LowPart;
+
+                        SYSTEMTIME st_Diff;
+                        if (FileTimeToSystemTime(&ft_Diff, &st_Diff))
+                        {
+                            sprintf(Duration, "%02hd:%02hd:%02hd.%03hd", st_Diff.wHour, st_Diff.wMinute, st_Diff.wSecond, st_Diff.wMilliseconds);
+                        }
+                        else
+                            strcpy(Duration, "            ");
+                    }
+                    else
+                        strcpy(Duration, "            ");
+
+                }
+                else
+                    strcpy(Duration, "            ");
+            }
+            else
+            {
+                st_In=st;
+                strcpy(Duration, "            ");
+            }
+
+            fprintf(F,"                                       %02hd:%02hd:%02hd.%03hd %s", st.wHour, st.wMinute, st.wSecond, st.wMilliseconds, Duration);
+        }
+
+        void Debug_Close()
+        {
+            Debug += "\r\n";
+            fwrite(Debug.c_str(), Debug.size(), 1, F); \
+            fclose(F);
+        }
+    }
+    using namespace ZenLib_Dir_Debug;
+
+    #define ZENLIB_DEBUG1(_NAME,_TOAPPEND) \
+        Debug_Open(false); \
+        Debug+=", ";Debug+=_NAME; \
+        _TOAPPEND; \
+        Debug_Close();
+
+    #define ZENLIB_DEBUG2(_NAME,_TOAPPEND) \
+        Debug_Open(true); \
+        Debug+=", ";Debug+=_NAME; \
+        _TOAPPEND; \
+        Debug_Close();
+#else // ZENLIB_DEBUG
+    #define ZENLIB_DEBUG1(_NAME,_TOAPPEND)
+    #define ZENLIB_DEBUG2(_NAME,_TOAPPEND)
+#endif // ZENLIB_DEBUG
+
 //***************************************************************************
 // Constructor/Destructor
 //***************************************************************************
@@ -56,6 +147,9 @@ namespace ZenLib
 
 ZtringList Dir::GetAllFileNames(const Ztring &Dir_Name_, dirlist_t Options)
 {
+    ZENLIB_DEBUG1(     "Dir GetAllFileNames",
+                        Debug+=", Dir_Name="; Debug+=Ztring(Dir_Name_).To_UTF8(); Debug+=", Options="; Debug +=Ztring::ToZtring(Options).To_UTF8())
+
     ZtringList ToReturn;
     Ztring Dir_Name=Dir_Name_;
 
@@ -101,63 +195,34 @@ ZtringList Dir::GetAllFileNames(const Ztring &Dir_Name_, dirlist_t Options)
             Ztring Path=FileName::Path_Get(Dir_Name);
             if (Path.empty())
             {
-                #ifdef UNICODE
-                    #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                    if (IsWin9X_Fast())
-                    {
-                        DWORD Path_Size=GetFullPathNameA(Dir_Name.To_Local().c_str(), 0, NULL, NULL);
-                        char* PathTemp=new char[Path_Size+1];
-                        if (GetFullPathNameA(Dir_Name.To_Local().c_str(), Path_Size+1, PathTemp, NULL))
-                            Path=FileName::Path_Get(PathTemp);
-                        delete [] PathTemp; //PathTemp=NULL;
-                    }
-                    else
-                    #endif //ZENLIB_NO_WIN9X_SUPPORT
-                    {
-                        DWORD Path_Size=GetFullPathName(Dir_Name.c_str(), 0, NULL, NULL);
-                        Char* PathTemp=new Char[Path_Size+1];
-                        if (GetFullPathNameW(Dir_Name.c_str(), Path_Size+1, PathTemp, NULL))
-                            Path=FileName::Path_Get(PathTemp);
-                        delete [] PathTemp; //PathTemp=NULL;
-                    }
-                #else
-                    DWORD Path_Size=GetFullPathName(Dir_Name.c_str(), 0, NULL, NULL);
-                    Char* PathTemp=new Char[Path_Size+1];
-                    if (GetFullPathName(Dir_Name.c_str(), Path_Size+1, PathTemp, NULL))
-                        Path=FileName::Path_Get(PathTemp);
-                    delete [] PathTemp; //PathTemp=NULL;
-                #endif //UNICODE
+                DWORD Path_Size=GetFullPathName(Dir_Name.c_str(), 0, NULL, NULL);
+                Char* PathTemp=new Char[Path_Size+1];
+                if (GetFullPathName(Dir_Name.c_str(), Path_Size+1, PathTemp, NULL))
+                    Path=FileName::Path_Get(PathTemp);
+                delete [] PathTemp;
             }
 
             #ifdef UNICODE
                 WIN32_FIND_DATAW FindFileDataW;
-                HANDLE hFind;
-                #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                WIN32_FIND_DATAA FindFileDataA;
-                if (IsWin9X_Fast())
-                    hFind=FindFirstFileA(Dir_Name.To_Local().c_str(), &FindFileDataA);
-                else
-                #endif //ZENLIB_NO_WIN9X_SUPPORT
-                    hFind=FindFirstFileW(Dir_Name.c_str(), &FindFileDataW);
+                HANDLE hFind=FindFirstFileW(Dir_Name.c_str(), &FindFileDataW);
             #else
                 WIN32_FIND_DATA FindFileData;
                 HANDLE hFind=FindFirstFile(Dir_Name.c_str(), &FindFileData);
             #endif //UNICODE
 
             if (hFind==INVALID_HANDLE_VALUE)
+            {
+                ZENLIB_DEBUG2(   "Dir GetAllFileNames",
+                                    Debug+=", returns with files count="; Debug +=Ztring::ToZtring(ToReturn.size()).To_UTF8())
+
                 return ZtringList();
+            }
 
             BOOL ReturnValue;
             do
             {
                 #ifdef UNICODE
-                    Ztring File_Name;
-                    #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                    if (IsWin9X_Fast())
-                        File_Name=FindFileDataA.cFileName;
-                    else
-                    #endif //ZENLIB_NO_WIN9X_SUPPORT
-                        File_Name=FindFileDataW.cFileName;
+                    Ztring File_Name(FindFileDataW.cFileName);
                 #else
                     Ztring File_Name(FindFileData.cFileName);
                 #endif //UNICODE
@@ -175,12 +240,7 @@ ZtringList Dir::GetAllFileNames(const Ztring &Dir_Name_, dirlist_t Options)
                         ToReturn.push_back(File_Name_Complete); //A file
                 }
                 #ifdef UNICODE
-                    #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                    if (IsWin9X_Fast())
-                        ReturnValue=FindNextFileA(hFind, &FindFileDataA);
-                    else
-                    #endif //ZENLIB_NO_WIN9X_SUPPORT
-                        ReturnValue=FindNextFileW(hFind, &FindFileDataW);
+                    ReturnValue=FindNextFileW(hFind, &FindFileDataW);
                 #else
                     ReturnValue=FindNextFile(hFind, &FindFileData);
                 #endif //UNICODE
@@ -249,6 +309,9 @@ ZtringList Dir::GetAllFileNames(const Ztring &Dir_Name_, dirlist_t Options)
         #endif
     #endif //ZENLIB_USEWX
 
+    ZENLIB_DEBUG2(   "Dir GetAllFileNames",
+                        Debug+=", files count="; Debug +=Ztring::ToZtring(ToReturn.size()).To_UTF8())
+
     return ToReturn;
 }
 
@@ -259,22 +322,23 @@ ZtringList Dir::GetAllFileNames(const Ztring &Dir_Name_, dirlist_t Options)
 //---------------------------------------------------------------------------
 bool Dir::Exists(const Ztring &File_Name)
 {
+    ZENLIB_DEBUG1(     "Dir Exists",
+                        Debug+=", Dir_Name="; Debug+=Ztring(File_Name).To_UTF8();)
+
     #ifdef ZENLIB_USEWX
         wxFileName FN(File_Name.c_str());
         return FN.DirExists();
     #else //ZENLIB_USEWX
        #ifdef WINDOWS
             #ifdef UNICODE
-                DWORD FileAttributes;
-                #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                if (IsWin9X_Fast())
-                    FileAttributes=GetFileAttributesA(File_Name.To_Local().c_str());
-                else
-                #endif //ZENLIB_NO_WIN9X_SUPPORT
-                    FileAttributes=GetFileAttributesW(File_Name.c_str());
+                DWORD FileAttributes=GetFileAttributesW(File_Name.c_str());
             #else
                 DWORD FileAttributes=GetFileAttributes(File_Name.c_str());
             #endif //UNICODE
+
+            ZENLIB_DEBUG2(   "Dir Exists",
+                                Debug+=", returns "; Debug +=Ztring::ToZtring(((FileAttributes!=INVALID_FILE_ATTRIBUTES) && (FileAttributes&FILE_ATTRIBUTE_DIRECTORY))?1:0).To_UTF8())
+
             return ((FileAttributes!=INVALID_FILE_ATTRIBUTES) && (FileAttributes&FILE_ATTRIBUTE_DIRECTORY));
         #else //WINDOWS
             struct stat buffer;
@@ -297,12 +361,7 @@ bool Dir::Create(const Ztring &File_Name)
     #else //ZENLIB_USEWX
         #ifdef WINDOWS
             #ifdef UNICODE
-                #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                if (IsWin9X_Fast())
-                    return CreateDirectoryA(File_Name.To_Local().c_str(), NULL)!=0;
-                else
-                #endif //ZENLIB_NO_WIN9X_SUPPORT
-                    return CreateDirectoryW(File_Name.c_str(), NULL)!=0;
+                return CreateDirectoryW(File_Name.c_str(), NULL)!=0;
             #else
                 return CreateDirectory(File_Name.c_str(), NULL)!=0;
             #endif //UNICODE
@@ -312,6 +371,161 @@ bool Dir::Create(const Ztring &File_Name)
     #endif //ZENLIB_USEWX
 }
 
+//***************************************************************************
+// GetAllFileNames
+//***************************************************************************
+
+#ifdef WINDOWS
+class GetAllFileNames_Private
+{
+public:
+    Ztring Dir_Name;
+    Ztring Path;
+    Dir::dirlist_t Options;
+    HANDLE hFind;
+    #ifdef UNICODE
+        WIN32_FIND_DATAW FindFileDataW;
+    #else
+        WIN32_FIND_DATA FindFileData;
+    #endif //UNICODE
+
+    GetAllFileNames_Private()
+        : hFind(INVALID_HANDLE_VALUE)
+    {
+    }
+};
+
+//---------------------------------------------------------------------------
+GetAllFileNames::GetAllFileNames()
+    : p(NULL)
+{
+}
+
+//---------------------------------------------------------------------------
+GetAllFileNames::~GetAllFileNames()
+{
+    Close();
+}
+
+//---------------------------------------------------------------------------
+void GetAllFileNames::Start  (const Ztring &Dir_Name_, Dir::dirlist_t Options_)
+{
+    ZENLIB_DEBUG1(     "GetAllFileNames Start",
+                        Debug+=", Dir_Name="; Debug+=Ztring(Dir_Name_).To_UTF8(); Debug+=", Options="; Debug +=Ztring::ToZtring(Options_).To_UTF8())
+
+    delete p; p=new GetAllFileNames_Private;
+    p->Dir_Name=Dir_Name_;
+    p->Options=Options_;
+
+    #ifdef WINDOWS
+        //Is a dir?
+        if (Dir::Exists(p->Dir_Name))
+            p->Dir_Name+=__T("\\*");
+
+        //Path
+        p->Path=FileName::Path_Get(p->Dir_Name);
+        if (p->Path.empty())
+        {
+            DWORD Path_Size=GetFullPathName(p->Dir_Name.c_str(), 0, NULL, NULL);
+            Char* PathTemp=new Char[Path_Size+1];
+            if (GetFullPathName(p->Dir_Name.c_str(), Path_Size+1, PathTemp, NULL))
+                p->Path=FileName::Path_Get(PathTemp);
+            delete [] PathTemp;
+        }
+    #else //WINDOWS
+    #endif
+
+    ZENLIB_DEBUG2(   "GetAllFileNames Start",
+                        )
+}
+
+bool GetAllFileNames::Next (Ztring& Name)
+{
+    if (!p)
+        return false;
+
+    ZENLIB_DEBUG1(     "GetAllFileNames Next",
+                        Debug+=",  Dir_Name="; Debug+=Ztring(p->Dir_Name).To_UTF8())
+
+    #ifdef WINDOWS
+        for (;;)
+        {
+            if (p->hFind==INVALID_HANDLE_VALUE)
+            {
+                #ifdef UNICODE
+                    p->hFind=FindFirstFileW(p->Dir_Name.c_str(), &p->FindFileDataW);
+                #else
+                    p->hFind=FindFirstFile(p->Dir_Name.c_str(), &p->FindFileData);
+                #endif //UNICODE
+
+                if (p->hFind==INVALID_HANDLE_VALUE)
+                    break;
+            }
+            else
+            {
+                BOOL ReturnValue;
+                #ifdef UNICODE
+                    ReturnValue=FindNextFileW(p->hFind, &p->FindFileDataW);
+                #else
+                    ReturnValue=FindNextFile(p->hFind, &p->FindFileData);
+                #endif //UNICODE
+                if (!ReturnValue)
+                    break;
+            }
+
+            #ifdef UNICODE
+                Ztring File_Name(p->FindFileDataW.cFileName);
+            #else
+                Ztring File_Name(p->FindFileData.cFileName);
+            #endif //UNICODE
+            if (File_Name!=__T(".") && File_Name!=__T("..")) //Avoid . an ..
+            {
+                bool IsOk=false;
+                #ifdef UNICODE
+                    if (p->FindFileDataW.dwFileAttributes&FILE_ATTRIBUTE_DIRECTORY)
+                #else
+                    if (p->FindFileData.dwFileAttributes&FILE_ATTRIBUTE_DIRECTORY)
+                #endif //UNICODE
+                {
+                    if (p->Options&Dir::Include_Dirs)
+                        IsOk=true; //A dir
+                }
+                else if ((p->Options&Dir::Include_Files) && ((p->Options&Dir::Include_Hidden) || (!File_Name.empty() && File_Name[0]!=__T('.'))))
+                    IsOk=true; //A file
+                if (IsOk)
+                {
+                    Name=p->Path+__T("\\")+File_Name;
+
+                    ZENLIB_DEBUG2(   "GetAllFileNames Next",
+                                        Debug+=", File_Name="; Debug +=Name.To_UTF8())
+
+                    return true;
+                }
+            }
+        }
+    #else //WINDOWS
+    #endif
+
+    Close();
+    return false;
+}
+
+void GetAllFileNames::Close ()
+{
+    if (!p)
+        return;
+
+    ZENLIB_DEBUG1(     "GetAllFileNames Close",
+                        Debug+=", Dir_Name="; Debug+=Ztring(p->Dir_Name).To_UTF8())
+
+    FindClose(p->hFind); p->hFind=INVALID_HANDLE_VALUE;
+    delete p; p=NULL;
+
+    ZENLIB_DEBUG2(   "GetAllFileNames Close",
+                        )
+}
+#endif //WINDOWS
+
 //***************************************************************************
 //
 //***************************************************************************
