@@ -51,6 +51,97 @@
 namespace ZenLib
 {
 
+//---------------------------------------------------------------------------
+// Debug
+#ifdef ZENLIB_DEBUG
+    #include <stdio.h>
+    #include <windows.h>
+    namespace ZenLib_File_Debug
+    {
+        FILE* F;
+        std::string Debug;
+        SYSTEMTIME st_In;
+
+        void Debug_Open(bool Out)
+        {
+            F=fopen("C:\\Temp\\ZenLib_Debug.txt", "a+t");
+            Debug.clear();
+            SYSTEMTIME st;
+            GetLocalTime( &st );
+
+            char Duration[100];
+            if (Out)
+            {
+                FILETIME ft_In;
+                if (SystemTimeToFileTime(&st_In, &ft_In))
+                {
+                    FILETIME ft_Out;
+                    if (SystemTimeToFileTime(&st, &ft_Out))
+                    {
+                        ULARGE_INTEGER UI_In;
+                        UI_In.HighPart=ft_In.dwHighDateTime;
+                        UI_In.LowPart=ft_In.dwLowDateTime;
+
+                        ULARGE_INTEGER UI_Out;
+                        UI_Out.HighPart=ft_Out.dwHighDateTime;
+                        UI_Out.LowPart=ft_Out.dwLowDateTime;
+
+                        ULARGE_INTEGER UI_Diff;
+                        UI_Diff.QuadPart=UI_Out.QuadPart-UI_In.QuadPart;
+
+                        FILETIME ft_Diff;
+                        ft_Diff.dwHighDateTime=UI_Diff.HighPart;
+                        ft_Diff.dwLowDateTime=UI_Diff.LowPart;
+
+                        SYSTEMTIME st_Diff;
+                        if (FileTimeToSystemTime(&ft_Diff, &st_Diff))
+                        {
+                            sprintf(Duration, "%02hd:%02hd:%02hd.%03hd", st_Diff.wHour, st_Diff.wMinute, st_Diff.wSecond, st_Diff.wMilliseconds);
+                        }
+                        else
+                            strcpy(Duration, "            ");
+                    }
+                    else
+                        strcpy(Duration, "            ");
+
+                }
+                else
+                    strcpy(Duration, "            ");
+            }
+            else
+            {
+                st_In=st;
+                strcpy(Duration, "            ");
+            }
+
+            fprintf(F,"                                       %02hd:%02hd:%02hd.%03hd %s", st.wHour, st.wMinute, st.wSecond, st.wMilliseconds, Duration);
+        }
+
+        void Debug_Close()
+        {
+            Debug += "\r\n";
+            fwrite(Debug.c_str(), Debug.size(), 1, F); \
+            fclose(F);
+        }
+    }
+    using namespace ZenLib_File_Debug;
+
+    #define ZENLIB_DEBUG1(_NAME,_TOAPPEND) \
+        Debug_Open(false); \
+        Debug+=", ";Debug+=_NAME; \
+        _TOAPPEND; \
+        Debug_Close();
+
+    #define ZENLIB_DEBUG2(_NAME,_TOAPPEND) \
+        Debug_Open(true); \
+        Debug+=", ";Debug+=_NAME; \
+        _TOAPPEND; \
+        Debug_Close();
+#else // ZENLIB_DEBUG
+    #define ZENLIB_DEBUG1(_NAME,_TOAPPEND)
+    #define ZENLIB_DEBUG2(_NAME,_TOAPPEND)
+#endif // ZENLIB_DEBUG
+
 //***************************************************************************
 // Constructor/Destructor
 //***************************************************************************
@@ -102,6 +193,9 @@ bool File::Open (const tstring &File_Name_, access_t Access)
 {
     Close();
 
+    ZENLIB_DEBUG1(      "File Open",
+                        Debug+=", File_Name="; Debug +=Ztring(File_Name_).To_UTF8();)
+
     File_Name=File_Name_;
 
     #ifdef ZENLIB_USEWX
@@ -162,33 +256,22 @@ bool File::Open (const tstring &File_Name_, access_t Access)
             DWORD dwDesiredAccess, dwShareMode, dwCreationDisposition;
             switch (Access)
             {
-                #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                case Access_Read         : dwDesiredAccess=IsWin9X_Fast()?GENERIC_READ:FILE_READ_DATA; dwShareMode=FILE_SHARE_READ|FILE_SHARE_WRITE; dwCreationDisposition=OPEN_EXISTING; break;
+                case Access_Read         : dwDesiredAccess=FILE_READ_DATA; dwShareMode=FILE_SHARE_READ|FILE_SHARE_WRITE; dwCreationDisposition=OPEN_EXISTING;   break;
                 case Access_Write        : dwDesiredAccess=GENERIC_WRITE;   dwShareMode=0;                                 dwCreationDisposition=OPEN_ALWAYS;   break;
-                case Access_Read_Write   : dwDesiredAccess=(IsWin9X_Fast()?GENERIC_READ:FILE_READ_DATA)|GENERIC_WRITE;   dwShareMode=0; dwCreationDisposition=OPEN_ALWAYS;   break;
-                case Access_Write_Append : dwDesiredAccess=GENERIC_WRITE;   dwShareMode=0;                                 dwCreationDisposition=OPEN_ALWAYS;   break;
-                #else // ZENLIB_NO_WIN9X_SUPPORT
-                case Access_Read         : dwDesiredAccess=FILE_READ_DATA; dwShareMode=FILE_SHARE_READ|FILE_SHARE_WRITE; dwCreationDisposition=OPEN_EXISTING; break;
-                case Access_Write        : dwDesiredAccess=GENERIC_WRITE;   dwShareMode=0;                                 dwCreationDisposition=OPEN_ALWAYS;   break;
-                case Access_Read_Write   : dwDesiredAccess=FILE_READ_DATA|GENERIC_WRITE;   dwShareMode=0; dwCreationDisposition=OPEN_ALWAYS;   break;
-                case Access_Write_Append : dwDesiredAccess=GENERIC_WRITE;   dwShareMode=0;                                 dwCreationDisposition=OPEN_ALWAYS;   break;
-                #endif //ZENLIB_NO_WIN9X_SUPPORT
+                case Access_Read_Write   : dwDesiredAccess=FILE_READ_DATA|GENERIC_WRITE;   dwShareMode=0; dwCreationDisposition=OPEN_ALWAYS;                    break;
+                case Access_Write_Append : dwDesiredAccess=GENERIC_WRITE;   dwShareMode=FILE_SHARE_READ|FILE_SHARE_WRITE; dwCreationDisposition=OPEN_ALWAYS;   break;
                 default                  : dwDesiredAccess=0;               dwShareMode=0;                                 dwCreationDisposition=0;             break;
             }
 
             #ifdef UNICODE
-                #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                if (IsWin9X_Fast())
-                    File_Handle=CreateFileA(File_Name.To_Local().c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
-                else
-                #endif //ZENLIB_NO_WIN9X_SUPPORT
-                    File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
+                File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
             #else
                 File_Handle=CreateFile(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
             #endif //UNICODE
+            #if 0 //Disabled
             if (File_Handle==INVALID_HANDLE_VALUE)
             {
-                //Sometime the file is locked for few milliseconds, we try again later
+                //Sometimes the file is locked for few milliseconds, we try again later
                 DWORD dw = GetLastError();
                 if (dw!=ERROR_FILE_NOT_FOUND)
                 {
@@ -204,20 +287,24 @@ bool File::Open (const tstring &File_Name_, access_t Access)
                     */
                     Sleep(1000);
                     #ifdef UNICODE
-                        #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                        if (IsWin9X_Fast())
-                            File_Handle=CreateFileA(Ztring(File_Name).To_Local().c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
-                        else
-                        #endif //ZENLIB_NO_WIN9X_SUPPORT
-                            File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
+                        File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
                     #else
                         File_Handle=CreateFile(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
                     #endif //UNICODE
                 }
             }
+            #endif //0
             if (File_Handle==INVALID_HANDLE_VALUE)
+            {
+                ZENLIB_DEBUG2(      "File Open",
+                                    Debug+=", returns 0";)
+
                 //File is not openable
                 return false;
+            }
+
+            ZENLIB_DEBUG2(      "File Open",
+                                Debug+=", returns 1";)
 
             //Append
             if (Access==Access_Write_Append)
@@ -233,6 +320,9 @@ bool File::Create (const Ztring &File_Name_, bool OverWrite)
 {
     Close();
 
+    ZENLIB_DEBUG1(      "File Create",
+                        Debug+=", File_Name="; Debug +=Ztring(File_Name_).To_UTF8();)
+
     File_Name=File_Name_;
 
     #ifdef ZENLIB_USEWX
@@ -291,33 +381,34 @@ bool File::Create (const Ztring &File_Name_, bool OverWrite)
             }
 
             #ifdef UNICODE
-                #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                if (IsWin9X_Fast())
-                    File_Handle=CreateFileA(File_Name.To_Local().c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
-                else
-                #endif //ZENLIB_NO_WIN9X_SUPPORT
-                    File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
+                File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
             #else
                 File_Handle=CreateFile(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
             #endif //UNICODE
+            #if 0 //Disabled
             if (File_Handle==INVALID_HANDLE_VALUE)
             {
                 //Sometime the file is locked for few milliseconds, we try again later
                 Sleep(3000);
                 #ifdef UNICODE
-                    #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                    if (IsWin9X_Fast())
-                        File_Handle=CreateFileA(File_Name.To_Local().c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
-                    else
-                    #endif //ZENLIB_NO_WIN9X_SUPPORT
-                        File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
+                    File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
                 #else
                     File_Handle=CreateFile(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
                 #endif //UNICODE
             }
+            #endif //0
             if (File_Handle==INVALID_HANDLE_VALUE)
+            {
+                ZENLIB_DEBUG2(      "File Create",
+                                    Debug+=", returns 0";)
+
                 //File is not openable
                 return false;
+            }
+
+            ZENLIB_DEBUG2(      "File Create",
+                                Debug+=", returns 1";)
+
             return true;
         #endif
     #endif //ZENLIB_USEWX
@@ -326,6 +417,24 @@ bool File::Create (const Ztring &File_Name_, bool OverWrite)
 //---------------------------------------------------------------------------
 void File::Close ()
 {
+    #ifdef ZENLIB_DEBUG
+        bool isOpen=false;
+        #ifdef ZENLIB_USEWX
+            if (File_Handle!=NULL)
+        #else //ZENLIB_USEWX
+            #ifdef ZENLIB_STANDARD
+                if (File_Handle!=NULL)
+            #elif defined WINDOWS
+                if (File_Handle!=INVALID_HANDLE_VALUE)
+            #endif
+        #endif //ZENLIB_USEWX
+            {
+                ZENLIB_DEBUG1(      "File Close",
+                                    Debug+=", File_Name="; Debug+=Ztring(File_Name).To_UTF8();)
+                isOpen=true;
+            }
+    #endif
+
     #ifdef ZENLIB_USEWX
         delete (wxFile*)File_Handle; File_Handle=NULL;
     #else //ZENLIB_USEWX
@@ -338,6 +447,14 @@ void File::Close ()
     #endif //ZENLIB_USEWX
     Position=(int64u)-1;
     Size=(int64u)-1;
+
+    #ifdef ZENLIB_DEBUG
+        if (isOpen)
+        {
+            ZENLIB_DEBUG2(      "File Close",
+                                )
+        }
+    #endif
 }
 
 //***************************************************************************
@@ -347,6 +464,9 @@ void File::Close ()
 //---------------------------------------------------------------------------
 size_t File::Read (int8u* Buffer, size_t Buffer_Size_Max)
 {
+    ZENLIB_DEBUG1(      "File Read",
+                        Debug+=", File_Name="; Debug+=Ztring(File_Name).To_UTF8(); Debug+=", MaxSize="; Debug +=Ztring::ToZtring(Buffer_Size_Max).To_UTF8())
+
     #ifdef ZENLIB_USEWX
         if (File_Handle==NULL)
     #else //ZENLIB_USEWX
@@ -380,10 +500,18 @@ size_t File::Read (int8u* Buffer, size_t Buffer_Size_Max)
             if (ReadFile(File_Handle, Buffer, (DWORD)Buffer_Size_Max, &Buffer_Size, NULL))
             {
                 Position+=Buffer_Size;
+
+                ZENLIB_DEBUG2(      "File Read",
+                                    Debug+=", new position ";Debug+=Ztring::ToZtring(Position).To_UTF8();;Debug+=", returns ";Debug+=Ztring::ToZtring((int64u)Buffer_Size).To_UTF8();)
+
                 return Buffer_Size;
             }
             else
+            {
+                ZENLIB_DEBUG2(      "File Read",
+                                    Debug+=", returns 0";)
                 return 0;
+            }
         #endif
     #endif //ZENLIB_USEWX
 }
@@ -443,11 +571,11 @@ bool File::Truncate (int64u Offset)
         return false;
 
     #ifdef ZENLIB_USEWX
-        return false; Not supported
+        return false; //Not supported
     #else //ZENLIB_USEWX
         #ifdef ZENLIB_STANDARD
             #if defined(WINDOWS)
-                return false; //No supported
+                return false; //Not supported
             #else //defined(WINDOWS)
                 //Need to close the file, use truncate, reopen it
                 if (Offset==(int64u)-1)
@@ -484,6 +612,9 @@ size_t File::Write (const Ztring &ToWrite)
 //---------------------------------------------------------------------------
 bool File::GoTo (int64s Position_ToMove, move_t MoveMethod)
 {
+    ZENLIB_DEBUG1(      "File GoTo",
+                        Debug+=", File_Name="; Debug+=Ztring(File_Name).To_UTF8(); Debug+="File GoTo: "; Debug +=Ztring(File_Name).To_UTF8(); Debug+=", MoveMethod="; Debug +=Ztring::ToZtring(MoveMethod).To_UTF8(); Debug+=", MaxSize="; Debug +=Ztring::ToZtring(Position_ToMove).To_UTF8())
+
     #ifdef ZENLIB_USEWX
         if (File_Handle==NULL)
     #else //ZENLIB_USEWX
@@ -522,13 +653,18 @@ bool File::GoTo (int64s Position_ToMove, move_t MoveMethod)
             ((fstream*)File_Handle)->seekg((streamoff)Position_ToMove, dir);
             return !((fstream*)File_Handle)->fail();
         #elif defined WINDOWS
-            LARGE_INTEGER GoTo; GoTo.QuadPart=Position_ToMove;
-            //return SetFilePointerEx(File_Handle, GoTo, NULL, MoveMethod)!=0; //Not on win9X
-            GoTo.LowPart=SetFilePointer(File_Handle, GoTo.LowPart, &GoTo.HighPart, MoveMethod);
-            if (GoTo.LowPart==INVALID_SET_FILE_POINTER && GetLastError()!=NO_ERROR)
-                return false;
-            else
-                return true;
+            LARGE_INTEGER GoTo;
+            GoTo.QuadPart=Position_ToMove;
+            BOOL i=SetFilePointerEx(File_Handle, GoTo, NULL, MoveMethod);
+
+            #ifdef ZENLIB_DEBUG
+                LARGE_INTEGER Temp; Temp.QuadPart=0;
+                SetFilePointerEx(File_Handle, Temp, &Temp, FILE_CURRENT);
+                ZENLIB_DEBUG2(      "File GoTo",
+                                    Debug+=", new position ";Debug+=Ztring::ToZtring(Temp.QuadPart).To_UTF8();Debug+=", returns ";Debug+=i?'1':'0';)
+            #endif //ZENLIB_DEBUG
+
+            return i?true:false;
         #endif
     #endif //ZENLIB_USEWX
 }
@@ -539,6 +675,9 @@ int64u File::Position_Get ()
     if (Position!=(int64u)-1)
         return Position;
 
+    ZENLIB_DEBUG1(      "File Position_Get",
+                        Debug+=", File_Name="; Debug+=Ztring(File_Name).To_UTF8())
+
     #ifdef ZENLIB_USEWX
         if (File_Handle==NULL)
     #else //ZENLIB_USEWX
@@ -560,6 +699,10 @@ int64u File::Position_Get ()
             LARGE_INTEGER GoTo; GoTo.QuadPart=0;
             GoTo.LowPart=SetFilePointer(File_Handle, GoTo.LowPart, &GoTo.HighPart, FILE_CURRENT);
             Position=GoTo.QuadPart;
+
+            ZENLIB_DEBUG2(      "File GoTo",
+                                Debug+=", new position ";Debug+=Ztring::ToZtring(GoTo.QuadPart).To_UTF8();Debug+=", returns 1";)
+
             return Position;
         #endif
     #endif //ZENLIB_USEWX
@@ -593,23 +736,23 @@ int64u File::Size_Get()
             File_Size=lseek(File_Handle, 0, SEEK_END);
             lseek(File_Handle, CurrentPos, SEEK_SET);
             */
-            streampos CurrentPos=((fstream*)File_Handle)->tellg();
-            if (CurrentPos!=(streampos)-1)
+            fstream::pos_type CurrentPos=((fstream*)File_Handle)->tellg();
+            if (CurrentPos!=(fstream::pos_type)-1)
             {
                 ((fstream*)File_Handle)->seekg(0, ios_base::end);
                 Size=((fstream*)File_Handle)->tellg();
-                ((fstream*)File_Handle)->seekg(CurrentPos, ios_base::beg);
+                ((fstream*)File_Handle)->seekg(CurrentPos);
             }
             else
                 Size=(int64u)-1;
-            return Size;
         #elif defined WINDOWS
-            DWORD High;DWORD Low=GetFileSize(File_Handle, &High);
-            if (Low==INVALID_FILE_SIZE && GetLastError()!=NO_ERROR)
-                return (int64u)-1;
-            Size=0x100000000ULL*High+Low;
-            return Size;
+                LARGE_INTEGER x = {0};
+                BOOL bRet = ::GetFileSizeEx(File_Handle, &x);
+                if (bRet == FALSE)
+                    return (int64u)-1;
+                Size=x.QuadPart;
         #endif
+        return Size;
     #endif //ZENLIB_USEWX
 }
 
@@ -712,7 +855,7 @@ Ztring File::Modified_Get()
             int Result=stat(File_Name.To_Local().c_str(), &Stat);
             if (Result<0)
                 return __T(""); //Error
-            Ztring Time; Time.Date_From_Seconds_1970(Stat.st_mtime);
+            Ztring Time; Time.Date_From_Seconds_1970((int64s)Stat.st_mtime);
             return Time;
         #elif defined WINDOWS
             FILETIME TimeFT;
@@ -820,6 +963,9 @@ Ztring File::Modified_Get(const Ztring &File_Name)
 //---------------------------------------------------------------------------
 bool File::Exists(const Ztring &File_Name)
 {
+    ZENLIB_DEBUG1(      "File Exists",
+                        Debug+=", File_Name="; Debug+=Ztring(File_Name).To_UTF8())
+
     #ifdef ZENLIB_USEWX
         wxFileName FN(File_Name.c_str());
         return FN.FileExists();
@@ -839,16 +985,14 @@ bool File::Exists(const Ztring &File_Name)
             if (File_Name.find(__T('*'))!=std::string::npos || (File_Name.find(__T("\\\\?\\"))!=0 && File_Name.find(__T('?'))!=std::string::npos) || (File_Name.find(__T("\\\\?\\"))==0 && File_Name.find(__T('?'), 4)!=std::string::npos))
                 return false;
             #ifdef UNICODE
-                DWORD FileAttributes;
-                #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                if (IsWin9X_Fast())
-                    FileAttributes=GetFileAttributesA(File_Name.To_Local().c_str());
-                else
-                #endif //ZENLIB_NO_WIN9X_SUPPORT
-                    FileAttributes=GetFileAttributesW(File_Name.c_str());
+                DWORD FileAttributes=GetFileAttributesW(File_Name.c_str());
             #else
                 DWORD FileAttributes=GetFileAttributes(File_Name.c_str());
             #endif //UNICODE
+
+            ZENLIB_DEBUG2(      "File Exists",
+                                Debug+=", File_Name="; Debug+=Ztring::ToZtring(((FileAttributes!=INVALID_FILE_ATTRIBUTES) && !(FileAttributes&FILE_ATTRIBUTE_DIRECTORY))?1:0).To_UTF8())
+
             return ((FileAttributes!=INVALID_FILE_ATTRIBUTES) && !(FileAttributes&FILE_ATTRIBUTE_DIRECTORY));
         #endif
     #endif //ZENLIB_USEWX
@@ -864,12 +1008,7 @@ bool File::Copy(const Ztring &Source, const Ztring &Destination, bool OverWrite)
             return false;
         #elif defined WINDOWS
             #ifdef UNICODE
-                #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                if (IsWin9X_Fast())
-                    return CopyFileA(Source.To_Local().c_str(), Destination.To_Local().c_str(), !OverWrite)!=0;
-                else
-                #endif //ZENLIB_NO_WIN9X_SUPPORT
-                    return CopyFileW(Source.c_str(), Destination.c_str(), !OverWrite)!=0;
+                return CopyFileW(Source.c_str(), Destination.c_str(), !OverWrite)!=0;
             #else
                 return CopyFile(Source.c_str(), Destination.c_str(), !OverWrite)!=0;
             #endif //UNICODE
@@ -891,12 +1030,7 @@ bool File::Move(const Ztring &Source, const Ztring &Destination, bool OverWrite)
             return !std::rename(Source.To_Local().c_str(), Destination.To_Local().c_str());
         #elif defined WINDOWS
             #ifdef UNICODE
-                #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                if (IsWin9X_Fast())
-                    return MoveFileA(Source.To_Local().c_str(), Destination.To_Local().c_str())!=0;
-                else
-                #endif //ZENLIB_NO_WIN9X_SUPPORT
-                    return MoveFileW(Source.c_str(), Destination.c_str())!=0;
+                return MoveFileW(Source.c_str(), Destination.c_str())!=0;
             #else
                 return MoveFile(Source.c_str(), Destination.c_str())!=0;
             #endif //UNICODE
@@ -918,12 +1052,7 @@ bool File::Delete(const Ztring &File_Name)
             #endif //UNICODE
         #elif defined WINDOWS
             #ifdef UNICODE
-                #ifndef ZENLIB_NO_WIN9X_SUPPORT
-                if (IsWin9X_Fast())
-                    return DeleteFileA(File_Name.To_Local().c_str())!=0;
-                else
-                #endif //ZENLIB_NO_WIN9X_SUPPORT
-                    return DeleteFileW(File_Name.c_str())!=0;
+                return DeleteFileW(File_Name.c_str())!=0;
             #else
                 return DeleteFile(File_Name.c_str())!=0;
             #endif //UNICODE
