@@ -77,6 +77,7 @@ string Hex2Char (unsigned char Char)
 }
 
 //---------------------------------------------------------------------------
+#ifndef WSTRING_MISSING
 wstring Hex2Char (wchar_t Char)
 {
     wstring Result;
@@ -84,6 +85,7 @@ wstring Hex2Char (wchar_t Char)
     Result+=(Char%16>=10?'a'-10:'0')+Char%16;
     return Result;
 }
+#endif //WSTRING_MISSING
 
 //***************************************************************************
 // URL manipulation
@@ -130,6 +132,7 @@ std::string URL_Encoded_Encode (const std::string& URL)
 }
 
 //---------------------------------------------------------------------------
+#ifndef WSTRING_MISSING
 std::wstring URL_Encoded_Encode (const std::wstring& URL)
 {
     wstring Result;
@@ -168,6 +171,7 @@ std::wstring URL_Encoded_Encode (const std::wstring& URL)
     }
     return Result;
 }
+#endif //WSTRING_MISSING
 
 //---------------------------------------------------------------------------
 std::string URL_Encoded_Decode (const std::string& URL)
@@ -193,6 +197,7 @@ std::string URL_Encoded_Decode (const std::string& URL)
 }
 
 //---------------------------------------------------------------------------
+#ifndef WSTRING_MISSING
 std::wstring URL_Encoded_Decode (const std::wstring& URL)
 {
     wstring Result;
@@ -214,6 +219,7 @@ std::wstring URL_Encoded_Decode (const std::wstring& URL)
     }
     return Result;
 }
+#endif //WSTRING_MISSING
 
 //***************************************************************************
 // Cleanup
