@@ -41,6 +41,7 @@
 #include <algorithm>
 #include <iomanip>
 #include <cmath>
+#include <ctime>
 #include "ZenLib/OS_Utils.h"
 #include "ZenLib/File.h"
 using namespace std;
@@ -221,6 +222,16 @@ bool Ztring::Assign_FromFile (const Ztring &FileName)
 // Conversions
 //***************************************************************************
 
+Ztring& Ztring::From_Unicode (const wchar_t S)
+{
+    #ifdef _UNICODE
+        append(1, S);
+    #else
+        From_Unicode(&S, 1);
+    #endif
+    return *this;
+}
+
 Ztring& Ztring::From_Unicode (const wchar_t* S)
 {
     if (S==NULL)
@@ -235,11 +246,6 @@ Ztring& Ztring::From_Unicode (const wchar_t* S)
                 assign(wxConvCurrent->cWC2MB(S));
         #else //ZENLIB_USEWX
             #ifdef WINDOWS
-                if (IsWin9X())
-                {
-                    clear();
-                    return *this; //Is not possible, UTF-8 is not supported by Win9X
-                }
                 int Size=WideCharToMultiByte(CP_UTF8, 0, S, -1, NULL, 0, NULL, NULL);
                 if (Size!=0)
                 {
@@ -344,7 +350,21 @@ Ztring& Ztring::From_UTF8 (const char* S)
                 {
                     if ((*(Z+1)&0xC0)==0x80 && (*(Z+2)&0xC0)==0x80 && (*(Z+3)&0xC0)==0x80)
                     {
-                        operator += ((((wchar_t)(*Z&0x0F))<<18)|((*(Z+1)&0x3F)<<12)||((*(Z+2)&0x3F)<<6)|(*(Z+3)&0x3F));
+                        #if defined(_MSC_VER)
+                            #pragma warning(push)
+                            #pragma warning(disable:4127)
+                        #endif //defined(_MSC_VER)
+                        if (sizeof(wchar_t) == 2)
+                        #if defined(_MSC_VER)
+                            #pragma warning(pop)
+                        #endif //defined(_MSC_VER)
+                        {
+                            int32u Value = ((((int32u)(*Z&0x0F))<<18)|((*(Z+1)&0x3F)<<12)|((*(Z+2)&0x3F)<<6)|(*(Z+3)&0x3F));
+                            operator += (0xD800|((Value>>10)-0x40));
+                            operator += (0xDC00| (Value&0x3FF));
+                        }
+                        else
+                            operator += ((((wchar_t)(*Z&0x0F))<<18)|((*(Z+1)&0x3F)<<12)|((*(Z+2)&0x3F)<<6)|(*(Z+3)&0x3F));
                         Z+=4;
                     }
                     else
@@ -718,12 +738,23 @@ Ztring& Ztring::From_CC4 (const int32u S)
     S1.append(1, (char)((S&0xFF000000)>>24));
     S1.append(1, (char)((S&0x00FF0000)>>16));
     S1.append(1, (char)((S&0x0000FF00)>> 8));
-    S1.append(1, (char)((S&0x000000FF)>> 0));
+    S1.append(1, (char)((S&0x000000FF)    ));
     From_Local(S1.c_str());
 
-    //Test
-    if (empty())
-        assign(__T("(empty)"));
+    // Validity Test
+    if ( size()==4
+     || (size()==3 && (S&0x000000FF)==0x00000000 && at(0)>=0x20 && at(1)>=0x20 && at(2)>=0x20)
+     || (size()==2 && (S&0x0000FFFF)==0x00000000 && at(0)>=0x20 && at(1)>=0x20)
+     || (size()==1 && (S&0x00FFFFFF)==0x00000000 && at(0)>=0x20))
+        return *this;
+
+    // Not valid, using 0x as fallback
+    clear();
+    append(__T("0x"));
+    append(Ztring().From_CC1((int8u)((S&0xFF000000)>>24)));
+    append(Ztring().From_CC1((int8u)((S&0x00FF0000)>>16)));
+    append(Ztring().From_CC1((int8u)((S&0x0000FF00)>> 8)));
+    append(Ztring().From_CC1((int8u)((S&0x000000FF)    )));
 
     return *this;
 }
@@ -995,7 +1026,7 @@ Ztring& Ztring::From_Number (const int64u I, int8u Radix)
             clear();
             return *this;
         }
-        Char* C1=new Char[65];
+        Char* C1=new Char[65]; C1[0] = 0;
         #ifdef __MINGW32__
             _ui64tot (I, C1, Radix);
         #else
@@ -1226,64 +1257,56 @@ Ztring& Ztring::Date_From_Milliseconds_1601 (const int64u Value)
 
 Ztring& Ztring::Date_From_Seconds_1601 (const int64u Value)
 {
-    if (Value>=11644473600LL) //Values <1970 are not supported
-        Date_From_Seconds_1970((int32u)(Value-11644473600LL));
-    else
-        clear(); //Not supported
+    return Date_From_Seconds_1970(((int64s)Value)-11644473600LL);
+}
 
-    return *this;
+Ztring& Ztring::Date_From_Seconds_1900 (const int32u Value)
+{
+    if (Value>2208988800)
+        return Date_From_Seconds_1970(((int64s)Value)-2208988800);
+    else
+        return Date_From_Seconds_1970(((int64s)Value)+0x100000000LL-2208988800); //Value is considering to loop e.g. NTP value
+}
+
+Ztring& Ztring::Date_From_Seconds_1900 (const int64s Value)
+{
+    return Date_From_Seconds_1970(Value-2208988800);
+}
+
+Ztring& Ztring::Date_From_Seconds_1904 (const int32u Value)
+{
+    return Date_From_Seconds_1970(((int64s)Value)-2082844800);
 }
 
 Ztring& Ztring::Date_From_Seconds_1904 (const int64u Value)
 {
-    #ifdef ZENLIB_USEWX
-        /*
-        wxDateTime Date;
-        Date.SetYear(1904);
-        Date.SetMonth(wxDateTime::Jan);
-        Date.SetDay(1);
-        Date.SetHour(0);
-        Date.SetMinute(0);
-        Date.SetSecond(0);
-        if (Value>=0x80000000)
-        {
-            //wxTimeSpan doesn't support unsigned int
-            int64u Value2=Value;
-            while (Value2>0x7FFFFFFF)
-            {
-                Date+=wxTimeSpan::Seconds(0x7FFFFFFF);
-                Value2-=0x7FFFFFFF;
-            }
-            Date+=wxTimeSpan::Seconds(Value2);
-        }
-        else
-            Date+=wxTimeSpan::Seconds(Value);
+    return Date_From_Seconds_1970(((int64s)Value)-2082844800);
+}
 
-        Ztring ToReturn=__T("UTC ");
-        ToReturn+=Date.FormatISODate();
-        ToReturn+=__T(" ");
-        ToReturn+=Date.FormatISOTime();
-
-        assign (ToReturn.c_str());
-        */ //WxDateTime is buggy???
-        if (Value>2082844800 && Value<2082844800+0x100000000LL) //Values <1970 and >2038 are not supported, 1970-01-01 00:00:00 is considered as not possible too
-            Date_From_Seconds_1970((int32u)(Value-2082844800));
-        else
-            clear(); //Not supported
-
-    #else //ZENLIB_USEWX
-        if (Value>2082844800 && Value<2082844800+0x100000000LL) //Values <1970 and >2038 are not supported, 1970-01-01 00:00:00 is considered as not possible too
-            Date_From_Seconds_1970((int32u)(Value-2082844800));
-        else
-            clear(); //Not supported
-    #endif //ZENLIB_USEWX
-    return *this;
+Ztring& Ztring::Date_From_Seconds_1904 (const int64s Value)
+{
+    return Date_From_Seconds_1970(Value-2082844800);
 }
 
 Ztring& Ztring::Date_From_Seconds_1970 (const int32u Value)
+{
+    return Date_From_Seconds_1970((int64s)Value);
+}
+
+Ztring& Ztring::Date_From_Seconds_1970 (const int32s Value)
+{
+    return Date_From_Seconds_1970((int64s)Value);
+}
+
+Ztring& Ztring::Date_From_Seconds_1970 (const int64s Value)
 {
     time_t Time=(time_t)Value;
     struct tm *Gmt=gmtime(&Time);
+    if (!Gmt)
+    {
+        clear();
+        return *this;
+    }
     Ztring DateT;
     Ztring Date=__T("UTC ");
     Date+=Ztring::ToZtring((Gmt->tm_year+1900));
@@ -1369,7 +1392,7 @@ Ztring& Ztring::Date_From_String (const char* Value, size_t Value_Size)
             ToReturn+=__T(" ");
             ToReturn+=Date.FormatISOTime();
         }
-        else if (ToReturn.size()<5)
+        else
             ToReturn+=DateS;
 
         assign (ToReturn.c_str());
@@ -1537,13 +1560,24 @@ std::string Ztring::To_UTF8 () const
             int32u wc; // must be unsigned.
 
             #if defined(_MSC_VER)
+                #pragma warning(push)
                 #pragma warning(disable:4127)
-            #endif //defined(__VISUALC__)
+            #endif //defined(_MSC_VER)
             if (sizeof(wchar_t) == 2)
             #if defined(_MSC_VER)
-                #pragma warning(default:4127)
-            #endif //defined(__VISUALC__)
+                #pragma warning(pop)
+            #endif //defined(_MSC_VER)
+            {
+                if (((*Z) & 0xFC00) == 0xD800)
+                {
+                    //UTF-16
+                    wc =( (((int16u) *Z) & 0x3FF) + 0x40) << 10;
+                    Z++;
+                    wc |= (((int16u) *Z) & 0x3FF);
+                }
+                else
                 wc = (int16u) *Z; // avoid a cast problem if wchar_t is signed.
+            }
             else
                 wc = *Z;
 
