@@ -285,7 +285,7 @@ void ZtringListList::Write(const Ztring &ToWrite)
 {
     clear();
 
-    if (!&ToWrite || !ToWrite.size())
+    if (ToWrite.empty())
         return;
 
     size_type PosC=0;
